aboutsummaryrefslogtreecommitdiff
path: root/test/fixedbugs/issue22794.go
diff options
context:
space:
mode:
Diffstat (limited to 'test/fixedbugs/issue22794.go')
-rw-r--r--test/fixedbugs/issue22794.go6
1 files changed, 3 insertions, 3 deletions
diff --git a/test/fixedbugs/issue22794.go b/test/fixedbugs/issue22794.go
index c7e9eb1224..2ac31ef0c7 100644
--- a/test/fixedbugs/issue22794.go
+++ b/test/fixedbugs/issue22794.go
@@ -13,8 +13,8 @@ type it struct {
func main() {
i1 := it{Floats: true}
- if i1.floats { // ERROR "(type it .* field or method floats, but does have Floats)"
+ if i1.floats { // ERROR "(type it .* field or method floats, but does have Floats)|undefined field or method"
}
- i2 := &it{floats: false} // ERROR "(but does have Floats)"
- _ = &it{InneR: "foo"} // ERROR "(but does have inner)"
+ i2 := &it{floats: false} // ERROR "(but does have Floats)|unknown field|declared but not used"
+ _ = &it{InneR: "foo"} // ERROR "(but does have inner)|unknown field"
}